pub struct WorstStaleEntry<T> {
pub element: T,
pub outcome: ElementOutcome,
pub known_index: usize,
pub known_time: Option<Duration>,
pub last_absent_index: Option<usize>,
pub last_absent_time: Option<Duration>,
pub stable_latency_ms: u64,
}Expand description
Detailed info about a stale element (for worst_stale reporting).
Fields
element: Toutcome: ElementOutcomeknown_index: usizeIndex and time when the element was first known to exist.
known_time: Option<Duration>last_absent_index: Option<usize>Index and time of the last read that didn’t observe the element.
last_absent_time: Option<Duration>stable_latency_ms: u64Latency in milliseconds until stable.